using System;

namespace LibraryBusiness
{
	/// <summary>
	/// Holds the title of a book in the library
	/// </summary>
public class Title
{

	/// <summary>
	/// Name of the book, e.g. "War and Peace"
	/// </summary>
	private string name ;

	/// <summary>
	/// Public property which allows users of the Title class
	/// to get and set the name property. At the moment no 
	/// validation is performed on the name, but this should be 
	/// added later.
	/// </summary>
	public string Name 
	{
		get 
		{
			return name;
		}
		set 
		{
			name = value;
		}
	}

		/// <summary>
		/// Constructs a title
		/// </summary>
		/// <param name="inName">the name of the title to be created</param>
		public Title( string inName)
		{
			Name = inName;
		}

		/// <summary>
		/// A list of actual physical copies of this title. A physical 
		/// copy of a title is called a book
		/// </summary>
		private System.Collections.ArrayList books = new System.Collections.ArrayList();

		/// <summary>
		/// Adds a book to the list of copies of this title. 
		/// </summary>
		/// <param name="bookToAdd">a reference to the book
		/// instance to be added to the list of books with this 
		/// title</param>
		public void AddBook ( Book bookToAdd ) 
		{
			books.Add (bookToAdd);
		}

		/// <summary>
		/// Provide a string version of the Title. Provides the name
		/// of the title and the unique ID of each book which is a 
		/// copy of this title
		/// </summary>
		/// <returns>string version of the title</returns>
		public override string ToString()
		{
			string result = name + "\n";

			foreach ( Book b in books ) 
			{
				result = result + "    " + b.ToString() + "\n" ;
			}
			return result ;
		}

	}

	/// <summary>
	/// Holds the information about a single physical instance of 
	/// a book. Each book is linked with a particular Title and has
	/// a unique ID by which it is known in the entire library stock
	/// </summary>
	public class Book 
	{
		/// <summary>
		/// Unique ID for the book. Set when the book is created and
		/// never changes
		/// </summary>
		private long id;

		/// <summary>
		/// Accessor for the book ID. Does not provide a way in which
		/// the ID can be changed.
		/// </summary>
		public long ID 
		{
			get 
			{
				return id;
			}
		}

		/// <summary>
		/// A reference to the title of this book.
		/// </summary>
		private Title bookTitle ;

		/// <summary>
		/// Accessor for the title. Does not allow the title to be
		/// changed.
		/// </summary>
		public Title BookTitle 
		{
			get 
			{
				return bookTitle;
			}
		}


		/// <summary>
		/// Book constructor. Makes a new instance of a book
		/// </summary>
		/// <param name="newID">the ID value of this new book. The ID value
		/// must be unique within the library</param>
		/// <param name="inBookTitle">The title of the book. A reference
		/// to the Title instance which holds the catalogue information
		/// about this particular book.</param>
		public Book ( long newID, Title inBookTitle ) 
		{
			id = newID;
			bookTitle = inBookTitle;
		}

		/// <summary>
		/// Provides a string description of the Book, in the form of 
		/// ID information. Does not provide a string description of the 
		/// Title, as printing a Title causes all the Books which are
		/// copies of that Title to be printed out.
		/// </summary>
		/// <returns></returns>
		public override string ToString()
		{
			return "Book id " + id;
		}
	}
}
